#
# spec file for package tuned
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         system_dir %{_prefix}/lib/%{name}/
%define         profile_dir %{system_dir}profiles/
Name:           tuned
Version:        2.25.1.0+git.889387b
Release:        1.1
Summary:        A dynamic adaptive system tuning daemon
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://github.com/redhat-performance/tuned
Source0:        tuned-%{version}.tar.xz
Source1:        tuned.rpmlintrc
# PATCH-FIX-OPENSUSE fix-allow-receive_sender-default.patch <allow receive_sender="com.redhat.com"/> allow receive_* is normally
# not needed as that is the default --<p.drouand@gmail.com>
Patch0:         fix-allow-receive_sender-default.patch
Patch1:         0001-tuned-consts-Fix-grub.cfg-path-in-SLE.patch
BuildRequires:  bash-completion
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  python3-dbus-python
# needed by check section
BuildRequires:  python3-pyudev
BuildRequires:  pkgconfig(systemd)
# need perf_bias now
Requires:       ethtool
Requires:       gawk
Requires:       hdparm
Requires:       polkit
Requires:       python3-configobj
Requires:       python3-dbus-python
Requires:       python3-decorator
Requires:       python3-linux-procfs
Requires:       python3-pyinotify
Requires:       python3-pyudev
Requires:       util-linux
Requires:       virt-what
Conflicts:      laptop-mode-tools
Conflicts:      tlp
BuildArch:      noarch
%{?systemd_requires}

%description
The tuned package contains a daemon that tunes system settings dynamically.
It does so by monitoring the usage of several system components periodically.
Based on that information components will then be put into lower or higher
power saving modes to adapt to the current usage. Currently only ethernet
network and ATA harddisk devices are implemented.

%package utils
Summary:        Disk and net statistic monitoring systemtap scripts
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       powertop

%description utils
This package contains utilities that can help you to fine tune your
system and manage tuned profiles.

%package utils-systemtap
Summary:        Disk and net statistic monitoring systemtap scripts
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       systemtap

%description utils-systemtap
This package contains several systemtap scripts to allow detailed
manual monitoring of the system. Instead of the typical IO/sec it collects
minimal, maximal and average time between operations to be able to
identify applications that behave power inefficient (many small operations
instead of fewer large ones).

%package gtk
Summary:        Disk and net statistic monitoring systemtap scripts - GTK GUI
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       powertop
Requires:       python3-gobject

%description gtk
GTK GUI that can control tuned and provide simple profile editor.

%package profiles-atomic
Summary:        Additional tuned profiles targeted to Atomic
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-atomic
Additional profile(s) for the tuned daemon, targeted to Atomic host and guest.

%package profiles-nfv
Summary:        Additional tuned profiles targeted to Network Function Virtualization (NFV)
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-nfv
Additional profile(s) for the tuned daemon, targeted to Network Function Virtualization (NFV).

%package profiles-openshift
Summary:        Additional tuned profile(s) optimized for the OpenShift platform
Requires:       %{name} = %{version}

%description profiles-openshift
Additional 3 profiles for the Openshift platform:
A parent profile containing tuning shared by OpenShift control plane and worker nodes.
One profile optimized for OpenShift control plane.
And a third profile optimized for general workloads on OpenShift worker nodes.

%package profiles-oracle
Summary:        Additional tuned profiles targeted to Oracle loads
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-oracle
Additional profile(s) for the tuned daemon,  targeted to Oracle loads.

%package profiles-postgresql
Summary:        Additional tuned profile(s) targeted to PostgreSQL server loads
Requires:       %{name} = %{version}

%description profiles-postgresql
Additional tuned profile(s) targeted to PostgreSQL server loads.

%package profiles-realtime
Summary:        Additional tuned profiles targeted to realtime
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-realtime
Additional profile(s) for the tuned daemon, targeted to realtime.

# Do not ship SAP profiles for SLE and Leap, there are other packages
# providing these profiles (starting with ALP these are included again)
%if !0%{?sle_version} || %{?suse_version} >= 1599
%package profiles-sap
Summary:        Additional tuned profile(s) targeted to SAP NetWeaver loads
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-sap
Additional profile(s) for the tuned daemon, targeted to SAP NetWeaver loads.

%package profiles-sap-hana
Summary:        Additional tuned profile(s) targeted to SAP HANA loads
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-sap-hana
Additional profile(s) for the tuned daemon, targeted to SAP HANA loads.
%endif

%package profiles-spectrumscale
Summary:        Additional tuned profile(s) optimized for IBM Spectrum Scale
Requires:       %{name} = %{version}

%description profiles-spectrumscale
Additional tuned profile(s) optimized for IBM Spectrum Scale.

%package ppd
Summary:        PPD compatibility daemon
Requires:       %{name} = %{version}
Conflicts:      ppd-service
# The compatibility daemon is swappable for power-profiles-daemon
Provides:       ppd-service

%description ppd
An API translation daemon that allows applications to easily transition
to TuneD from power-profiles-daemon (PPD).

%prep
%autosetup -p1

%build
# The tuned daemon is written in pure Python. Nothing requires to be built.
# Just a hack to avoid installation in a wrong directory
sed -i 's|$(SYSCONFDIR)/modprobe.d|%{_modprobedir}|' Makefile
sed -i 's|$(SYSCONFDIR)/dbus-1/system.d|%{_datadir}/dbus-1/system.d|' Makefile

%install
%make_install LIBEXECDIR=%{_prefix}/lib TUNED_PROFILES_DIR=%{profile_dir}
make install-ppd DESTDIR=%{buildroot} TUNED_PROFILES_DIR=%{profile_dir}
# we do not have the python perf module (see bsc #1217758)
rm %{buildroot}/%{python3_sitelib}/tuned/plugins/plugin_{scheduler,irqbalance}.py
%py3_compile %{buildroot}/%{python3_sitelib}
rm -rf %{buildroot}/%{_datadir}/doc
# Remove unwanted stuff instead of excluding them in files list
rm -rf %{buildroot}%{profile_dir}/{default,desktop-powersave,laptop-ac-powersave,server-powersave,laptop-battery-powersave,enterprise-storage,spindown-disk}
rm %{buildroot}%{_mandir}/man7/tuned-profiles-compat.7
%if 0%{?suse_version} < 1600
ln -sf service %{buildroot}%{_sbindir}/rctuned
%endif

%if 0%{?sle_version} && %{?suse_version} < 1599
rm -r %{buildroot}%{profile_dir}/sap-netweaver
rm -r %{buildroot}%{profile_dir}/sap-hana
rm %{buildroot}%{_mandir}/man7/tuned-profiles-sap.7
rm %{buildroot}%{_mandir}/man7/tuned-profiles-sap-hana.7
%endif

%check
make test PYTHON=python3

%post
%tmpfiles_create %{name}.conf
%systemd_post %{name}.service

# migrate all user-defined profiles from /etc/tuned/ to /etc/tuned/profiles/
for f in %{_sysconfdir}/tuned/*; do
  if [ -e "$f/tuned.conf" ]; then
    mv -n "$f" %{_sysconfdir}/tuned/profiles/
  fi
done

%post ppd
%systemd_post %{name}-ppd.service

%pre
%systemd_pre %{name}.service
# Avoid restoring outdated stuff in posttrans
[ ! -f "%{_sysconfdir}/modprobe.d/tuned.conf.rpmsave" ] || \
  mv -f "%{_sysconfdir}/modprobe.d/tuned.conf.rpmsave" "%{_sysconfdir}/modprobe.d/tuned.conf.rpmsave.old" || :

%pre ppd
%systemd_pre %{name}-ppd.service

%posttrans
# Migration of modprobe.conf files to _modprobedir
[ ! -f "%{_sysconfdir}/modprobe.d/tuned.conf.rpmsave" ] || \
  mv -fv "%{_sysconfdir}/modprobe.d/tuned.conf.rpmsave" "%{_sysconfdir}/modprobe.d/tuned.conf" || :

%preun
%service_del_preun %{name}.service

%preun ppd
%service_del_preun %{name}-ppd.service

%postun
%service_del_postun %{name}.service

%postun ppd
%service_del_postun %{name}-ppd.service

%files
%license COPYING
%doc AUTHORS README.md
%{_datadir}/bash-completion/completions/tuned-adm
%{_datadir}/polkit-1/actions/com.redhat.tuned.policy
%{python3_sitelib}/tuned
%{_sbindir}/tuned
%{_sbindir}/tuned-adm
%if 0%{?suse_version} < 1600
%{_sbindir}/rctuned
%endif
%dir %{system_dir}
%dir %{system_dir}/recommend.d
%exclude %{python3_sitelib}/tuned/gtk

# General files
%{system_dir}/pmqos-static.py
%{system_dir}/functions
%{system_dir}/recommend.d/50-tuned.conf
%{system_dir}/defirqaffinity.py

%if 0%{?sle_version} && %{?suse_version} < 1599
%exclude %{profile_dir}/sap-netweaver
%exclude %{profile_dir}/sap-hana
%exclude %{profile_dir}/sap-hana-kvm-guest
%exclude %{_mandir}/man7/tuned-profiles-sap.7%{?ext_man}
%exclude %{_mandir}/man7/tuned-profiles-sap-hana.7%{?ext_man}
%endif

# Profiles included in main package - alphabetically sorted
%dir %{profile_dir}
%{profile_dir}/accelerator-performance
%{profile_dir}/aws
%{profile_dir}/balanced
%{profile_dir}/balanced-battery
%{profile_dir}/cpu-partitioning
%{profile_dir}/cpu-partitioning-powersave
%{profile_dir}/desktop
%{profile_dir}/hpc-compute
%{profile_dir}/intel-sst
%{profile_dir}/latency-performance
%{profile_dir}/mssql
%{profile_dir}/network-latency
%{profile_dir}/network-throughput
%{profile_dir}/optimize-serial-console
%{profile_dir}/powersave
%{profile_dir}/throughput-performance
%{profile_dir}/virtual-guest
%{profile_dir}/virtual-host

# active_profile might be empty when built via build service, but typically
# not on a real install -> better do not mark it %%ghost
%config(noreplace) %{_sysconfdir}/tuned/active_profile
%config(noreplace) %{_sysconfdir}/tuned/ppd_base_profile
%config(noreplace) %{_sysconfdir}/tuned/cpu-partitioning-variables.conf
%config(noreplace) %{_sysconfdir}/tuned/cpu-partitioning-powersave-variables.conf
%config(noreplace) %{_sysconfdir}/tuned/tuned-main.conf
%config(noreplace) %{_sysconfdir}/tuned/profile_mode
%config(noreplace) %{_sysconfdir}/tuned/profiles
%config(noreplace) %{_sysconfdir}/tuned/post_loaded_profile
%config(noreplace) %verify(not size mtime md5) %{_sysconfdir}/tuned/bootcmdline
%config %{_sysconfdir}/grub.d
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/tuned.service
%{_modprobedir}/tuned.conf
%{_datadir}/dbus-1/system.d/com.redhat.tuned.conf
%attr(750, root, root) %dir %{_localstatedir}/log/tuned
%dir %{_sysconfdir}/tuned
%{_mandir}/man5/tuned*
%{_mandir}/man7/tuned-profiles-cpu-partitioning.7%{?ext_man}
%{_mandir}/man7/tuned-profiles.7%{?ext_man}
%{_mandir}/man7/tuned-profiles-mssql.7%{?ext_man}
%{_mandir}/man8/tuned*
%dir %{_datadir}/tuned
%ghost %dir /run/tuned
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/92-tuned.install

%files gtk
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*/
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/tuned-gui.desktop
%{_sbindir}/tuned-gui
%{python3_sitelib}/tuned/gtk
%{_datadir}/tuned/ui

%if !0%{?sle_version} || %{?suse_version} >= 1599
%files profiles-sap
%{profile_dir}/sap-netweaver
%{_mandir}/man7/tuned-profiles-sap.7%{?ext_man}

%files profiles-sap-hana
%{profile_dir}/sap-hana
%{profile_dir}/sap-hana-kvm-guest
%{_mandir}/man7/tuned-profiles-sap-hana.7%{?ext_man}
%endif

%files profiles-atomic
%{profile_dir}/atomic-host
%{profile_dir}/atomic-guest
%{_mandir}/man7/tuned-profiles-atomic.7%{?ext_man}

%files profiles-realtime
%config(noreplace) %{_sysconfdir}/tuned/realtime-variables.conf
%{profile_dir}/realtime
%{_mandir}/man7/tuned-profiles-realtime.7%{?ext_man}

%files profiles-oracle
%{profile_dir}/oracle
%{_mandir}/man7/tuned-profiles-oracle.7%{?ext_man}

%files profiles-nfv
%config(noreplace) %{_sysconfdir}/tuned/realtime-virtual-guest-variables.conf
%config(noreplace) %{_sysconfdir}/tuned/realtime-virtual-host-variables.conf
%{profile_dir}/realtime-virtual-guest
%{profile_dir}/realtime-virtual-host
%{_mandir}/man7/tuned-profiles-nfv-*.7%{?ext_man}

%files profiles-postgresql
%defattr(-,root,root,-)
%{profile_dir}/postgresql
%{_mandir}/man7/tuned-profiles-postgresql.7*

%files profiles-spectrumscale
%defattr(-,root,root,-)
%{profile_dir}/spectrumscale-ece
%{_mandir}/man7/tuned-profiles-spectrumscale-ece.7*

%files profiles-openshift
%defattr(-,root,root,-)
%{profile_dir}/openshift-control-plane
%{profile_dir}/openshift-node
%{profile_dir}/openshift
%{_mandir}/man7/tuned-profiles-openshift.7%{?ext_man}

%files utils
%license COPYING
%{_bindir}/powertop2tuned

%files utils-systemtap
%license COPYING
%doc doc/README.utils doc/README.scomes
%{_sbindir}/varnetload
%{_sbindir}/netdevstat
%{_sbindir}/diskdevstat
%{_sbindir}/scomes
%{_mandir}/man8/varnetload.*
%{_mandir}/man8/netdevstat.*
%{_mandir}/man8/diskdevstat.*
%{_mandir}/man8/scomes.*

%files ppd
%{_sbindir}/tuned-ppd
%{_unitdir}/tuned-ppd.service
%{_datadir}/dbus-1/system-services/net.hadess.PowerProfiles.service
%{_datadir}/dbus-1/system.d/net.hadess.PowerProfiles.conf
%{_datadir}/polkit-1/actions/net.hadess.PowerProfiles.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.UPower.PowerProfiles.service
%{_datadir}/dbus-1/system.d/org.freedesktop.UPower.PowerProfiles.conf
%{_datadir}/polkit-1/actions/org.freedesktop.UPower.PowerProfiles.policy
%config(noreplace) %{_sysconfdir}/tuned/ppd.conf

%changelog
* Tue Feb  4 2025 trenn@suse.de
- Add LIBEXECDIR=%%{_prefix}/lib to adopt libexecdir and remove
  the sed hack in spec due to mainline git 410344b8dbc64bada45be
- Update to version 2.25.1.0+git.889387b:
  * new release (2.25.1)
  * disk: Add missing remove parameter
  * plugins: Add missing instance parameters
  * Makefile: Add support for installation to custom $LIBEXECDIR
  * new release (2.25.0)
  * plugin_scheduler: add switch to disable processing of kthreads
  * sap-hana: Set transparent_hugepages to madvise
  * bootloader: export Grub variables to make them available in submenus
  * functions: Create a new parser object for each string expansion
  * utils: Rename `PluginLoader` to `ClassLoader`
  * plugin_net: handle cqe-mode-rx ethtool option
  * profiles: Correct CPU governor settings
  * utils.commands: Fix CPU online detection when not present
  * new release (2.25.0-rc.1)
  * docs: fixed docs generation on centos-7
  * plugin_scheduler: fixed API
  * plugin_scheduler: make perf support optional
  * plugin_net: added support for hotplug and rename
  * scheduler: Postpone cgroup blacklist check and double-check after fail
  * makefile: added support for installation to custom $BINDIR/$SBINDIR
  * tuned-ppd: Do not always clear holds with TuneD profile change signal
  * tuned-ppd: Check that TuneD profile change signal is relevant
  * doc: enable documentation generation on RHEL with asciidoc
  * scheduler: Log process info when its affinity cannot be changed
* Mon Jan 27 2025 Gabriel Krisman Bertazi <gabriel.bertazi@suse.com>
- Fix grub.cfg path (bsc#1236491)
  A 0001-tuned-consts-Fix-grub.cfg-path-in-SLE.patch
* Wed Jan 22 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks for CODE16 (PED-266).
* Fri Jan 17 2025 trenn@suse.de
- Update to version 2.24.1.50+git.13dfc68:
  * scheduler: updated sched knobs for kernels 6.6+
  * plugin_cpu: allow raw energy_performance_preference values
  * Do not initialize kvm low latency if kvm not present
- Do not conflict with power-profiles-daemon, this is managed via
  ppd-service in the tuned-ppd subpackage (bsc#1234754)
* Thu Jan 16 2025 trenn@suse.de
- Update to version 2.24.1.44+git.cc168b9:
  * tuned-ppd: Remove the use of StrEnum
  * tuned-ppd: Disallow releasing profile holds of other processes
  * tuned-ppd: Unify polkit policy with power-profiles-daemon
  * Obsolete power-profiles-daemon
  * Document new vm plugin options
  * Adjust profiles to set dirty_(bytes|ratio) via the vm plugin
  * vm: Add support for dirty_(bytes|ratio) sysctl parameters
  * tuned-ppd: Support the new UPower PPD namespace
  * tuned-ppd: Enable changing profile via function keys
  * tuned-ppd: Use inotify to check for performance degradation
  * tuned-ppd: Require the presence of the balanced profile
  * tuned-ppd: Add the version property
  * tuned-ppd: Add docstrings
  * tuned-ppd: Keep track of active and base profile
  * tuned-ppd: Fix UPower signal handler initialization
  * Add variables to BLS entries only if grub is used
  * powertop2tuned: use default user profile path from the consts
  * tuned-ppd: Use effective hold profile when adding profile holds
  * Bump doc/manual revision date and number
  * Clean up plugin docstrings
  * Add a script for generation of plugin docs from docstrings
  * scheduler: Do not assume that perf events have type attribute
  * Fix the error in the raise statement of check_positive()
  * fix: expand variables in Plugin._verify_all_device_commands
  * Allow shared service drop-in directory
  * drop support for cpuspeed
  * Parse no_turbo cpu plugin option using commands.get_bool
* Tue Dec 17 2024 Mel Gorman <mgorman@suse.com>
- Move gobject dependency to gtk package as it is the only utility that
  imports gi.
* Tue Dec 17 2024 Mel Gorman <mgorman@suse.com>
- Remove unnecessary cpupower dependency, sysfs fallback is used instead.
* Thu Nov 28 2024 trenn@suse.de
- Fix below security issues found by SUSE security review of latest
  polkit API additions. Kudos go to Matthias Gerstner (bsc#1232412)
- fixed privileged execution of arbitrary scripts by active local user
  resolves: CVE-2024-52336
- added sanity checks for API methods parameters
  resolves: CVE-2024-52337
- Update to version 2.24.1.0+git.90c24ee:
  * new release (2.24.1)
  * spec: used macro for profiles path and other fixes
  * realtime: remove leftover use of tuna
* Sat Oct 26 2024 Thomas Renninger <trenn@suse.de>
- Correct service cleanup calls in preun and postun scripts
- Move tmpfile_create before service_add_post
- Added python3-pyudev and python3-dbus-python as BuildRequires
  for added check section
- Move user defined profiles
  from /etc/tuned/
  into subdirs /etc/tuned/PROFILE
  via spec's %%post routine
- Enable make test in check section
- Update has at least parts of jsc#PED-10695
* Sun Aug 25 2024 pallaswept@proton.me
- Migrate profiles to /etc/tuned/profiles/ and /usr/lib/tuned/profiles/
  * Per upstream #615 and #609
- Update to version 2.24.0.2+git.c082797:
  * controller init: set _on_battery before switching profile
- New release (2.24.0)
  * Clear plugin repository when stopping tuning
  * man: add description of the balanced-battery profile
- New release (2.24.0-rc.1)
  * chore: remove dead irqbalance functions
  * plugin_irqbalance: switch to IRQBALANCE_BANNED_CPULIST
  * hotplug: wait for device initialization
  * Add `functions` to the files copied by the release-cp Makefile target
  * Add package2cpus and packages2uncores matcher functions
  * uncore: Allow to configure frequency limits using percent
  * plugin_scheduler: Adjust error logging in _set_affinity
  * fix: expand variables in plugin_irq
  * tests: Restore TuneD service after the error messages test
  * tests: Do not run tunedDisableSystemdRateLimitingStart via rlRun
  * Enable controller reset for audio by default
  * tuned-ppd: Adjust log message emitted when battery status changes
  * tuned-ppd: Refactor daemon initialization
  * tuned-ppd: Remove magic constant "unknown"
  * Add support for controlling amd-pstate core performance boost
  * spec: Start tuned-ppd right away if swapping from active PPD
  * spec: Add standard systemd scriptlet macros for tuned-ppd
  * tuned-ppd: Remove PIDFile from the systemd service file
  * tuned-ppd: Add an option to log to a file
  * Install script functions and recommend.d to /usr/lib/tuned/
  * Rename TUNED_PROFILESDIR to TUNED_PROFILES_DIR
  * CNF-13015: Fix helper function not accessing the correct return result
  * CNF-13015: Add helper function to run `lscpu` and parse result using regex
    parameters - This is similar to the cpuinfo function that reads from
    /proc/cpuinfo - Unfortunately that function was insufficient for our needs
    as we need to identify both the Vendor and Architecture reliably
* Sat Jun 22 2024 tobi.goergens@gmail.com
- Update to version 2.23.0.2+git.5d5dbfc:
  * chore: remove use of deprecated Logger.warn()
  * new release (2.23.0)
  * Disk plugin: make hdparm device checks lazy
  * Revert "Video plugin: make hdparm device checks lazy"
  * Video plugin: make hdparm device checks lazy
  * Do not check for x86_energy_perf_policy if it won't be used
  * Check that writes are necessary if they may cause redundant IPIs
  * Add an option to skip `write_to_file` if the content would not change
  * Turn on amdgpu panel power savings in balanced-battery
  * Modify the video plugin for tuning of the amdgpu `panel_power_savings` attribute
  * video: Don't show error when trying to read radeon files
  * video: make missing radeon_powersave files quieter
  * video: Rename _radeon_powersave_files to _files
  * feat: add plugin_irq
  * throughput-performance: dropped unused AMD related variable
  * ppd: Adjust the detection of 'performance-degraded'
  * ppd: Fix hold releasing
  * ppd: Add debug logs when changing base profile
  * Re-check dbus when (re)starting TuneD from tuned-adm profile
  * functions: added 'log' which helps with debugging
  * Simplify reading/writing from/to sysctl by using existing functions
  * Fix logs in `commands.read_file`
  * plugin_cpu: decrease the severity of _has_pm_qos==False
  * sap-netweaver: increased vm.max_map_count
  * daemon: buffer sighup signal
  * tuned-ppd: Detect battery change events
  * Migrate profiles to /etc/tuned/profiles/ and /usr/lib/tuned/profiles/
  * Propagate unexpected exceptions in the wait exception handler
  * Add an option to configure profile directories
  * Use get_list to parse unix_socket_signal_path
  * Add a function to parse lists in the global configuration
  * Added intel_recommended_pstate builtin function.
  * dbus: add commands to dynamically create/destroy instances
  * dbus: ensure that hotplug operations only work on hotplug plugins
  * instance: add priority as a property
  * monitor_net: fixed traceback if stats cannot be read
  * plugin_net: do not read monitors if dynamic tuning is disabled
  * Allow equal characters in parameter value
* Thu Feb 29 2024 trenn@suse.de
- Update to version 2.22.1.2+git.86ac977:
  * fix-error
  * new release (2.22.1)
  * Rename plugin_intel_uncore.py to plugin_uncore.py
  * Rename IntelUncorePlugin to UncorePlugin
  * network-throughput: increased net.ipv4.tcp_rmem default value
  * spec: cleanup, drop RHEL dynamic_tuning customization
  * new release (2.22.0)
- Polkit changes got accepted by security review (bsc#1220081)
* Fri Feb 16 2024 trenn@suse.de
- Update to version 2.22.0.rc.1.0+git.ad314ee:
  * Disable dynamic tuning by default
  * plugin_cpu: improved backward compat. of the pm_qos parser warnings
* Sun Feb 11 2024 trenn@suse.de
- Update to version 2.22.0-rc.1.0+git.ad314ee:
  * new release (2.22.0-rc.1)
  * Add missing install command for tuned-ppd.py
  * Fixes for intel uncore plugin
  * Add intel uncore plugin
  * scheduler: add option for ignoring IRQs affinity
  * Configure the PPD-to-TuneD daemon to work as a replacement of PPD
  * Implement the PPD-to-TuneD daemon
  * Make DBusExporter reusable for other services
  * Do not report errors on systems with no wifi
  * Add an ACPI plugin
  * plugin_cpu: Support cstate settings of `pm_qos_resume_latency_us`
  * Skip calling rpm-ostree kargs in no-op case
  * Expand sysctl plugin options when reporting overrides
  * profiles: add energy_performance_preference hints to profiles
  * hotplug: do not report ENOENT errors on device remove
  * profiles: Improve 'isolated_cores=' help text
  * Be explicit about amd-pstate support
  * Fixed REs escape sequences not to trigger SyntaxWarning
  * sap-hana-kvm-guest: fix whitespaces
  * Fix TextView to expand with window
* Mon Dec  4 2023 aschnell@suse.com
- do not package inoperable plugins (bsc#1217758)
* Wed Nov 15 2023 trenn@suse.de
- Update to version 2.21.0.17+git.5d3b469:
  * Add API functions to retrieve active instances and their devices
  * Add a tuned-adm command for moving devices between plugin instances
  * Add support for sysctl names with slash
  * Make all functions in plugin_sysctl.py methods of SysctlPlugin
  * RHEL-3689: Print all arguments of failing command in err_msg
  * style: fix inconsistent whitespace in plugin_cpu.py
  * Return 0 when ksm services do not exist
  * fix error
  * Converted SPEC file license to SPDX
* Fri Sep 15 2023 trenn@suse.de
- Update to version 2.21.0.0+git.670541d:
  * new release (2.21.0)
  * api: fixed stop method not to require any parameter
  * new release (2.21.0-rc.1)
  * gui: multiple fixes and warnings removal
  * gui: fixed inconsistent tabs and spaces, introduced by #516
  * Serialize SIGHUP processing
  * No errors when physical_package_id file does not exist
  * Update tests: disable systemd rate limiting.
  * network-latency: enable rcu_normal_after_boot=1 kernel parameter
  * remove ktimer_lockless_check sysfs setting from realtime-virtual profiles
  * move rtentsk to network-latency profile
  * move "tsc=reliable" setting from realtime to network-latency tuned configuration
  * unify common sysctl settings between realtime and cpu-partitioning profiles
  * Rename rollback-related constants and variables
  * Add rollback option to tuned-main.conf
  * Recast README into MarkDown with various minor corrections and improvements
  * Remove setting ip forwarding via openshift profile
  * Fix logging in [scheduler] plug-in
  * fixed sap-hana docu regarding processor power settings
  * Added sap-hana-kvm-guest profile
  * tests/beakerlib: Add new test which covers socket API.
  * plugin_net: expand variables properly
  * fix typo
  * add error dialog when no active profile set
* Fri Apr 14 2023 trenn@suse.de
- New polkit interface has been reviewed by security bsc#1185418
- Remove old outdated spec scripts before suse_version 1500
- Separate SAP and related profiles to not be installed in SLE 15 SPx
  and older, but add them with openSUSE (as before), ALP and upcoming
  SLE distros
- Update to version tuned-2.20.0.18+git.7b1a20b
  * scheduler: fix traceback if running with runtime=0
  * plugin_scheduler: fix perf fd leaks
  * Better log on unsupported hw for pm_qos_resume_latency_us option
  * fix-tuned-profiles-adoc-error
  * explicitly use /bin/bash for tuned scripts
  * set the icon in the about dialog
  * install dbus policy in /usr/share/dbus-1
  * tuned-adm: better error message for unauthorized switch_profile
  * man: updated manual pages to be more consistent
  * spec: dropped unneeded ncat dependency
  * fix log error
  * Report reapplied sysctls only on different values
  * Fixing no _evlist attribute when run without daemon
  * fix 'is_active' does not work
  * new release (2.20.0-rc.1)
  * build: fixed FTBFS with python2
  * Expose TuneD API to the Unix Domain Socket.
  * Inform users about reapplied sysctls
  * API: add support for moving devices between instances
  * throughput-performance: set net.core.somaxconn to at least 2048
  * Adding support for cpu intel_pstate scaling driver
  * configparser: use no strict parser to mimic old behavior
  * Adding pm_qos_resume_latency_us option for cpu plugin.i
  * Makefile: added fix for python-3.12
  * D-Bus: only send tracebacks through the D-Bus if in the debug mode
  * update vendor_url in policy file
  * correct section of the tuned-profiles-openshift manpage
  * Allow selecting a different pkg-config executable
  * fix tuned/gtk/gui_profile_loader.py spell error
  * bootloader: create bootcmdline even when skip_grub_config=true
  * profiles: added aws profile for aws ec2 instances
  * Closing fd from perf module in scheduler plugin
* Tue Dec 27 2022 trenn@suse.de
- Update to version 2.19.0.29+git.b894a3e:
  * Fix for catching exceptions in profile loader.
  * Add new cpu-partitioning-powersave profile
  * Add CodeQL workflow for GitHub code scanning
  * Fixed sysvinit path
  * systemd: relax polkit requirement
  * realtime-virtual-*: Tune priority of new ktimers threads
  * hpc-compute profile: Remove vm.hugepages_treat_as_movable
  * fix spelling error
  * Profile openshift: increase fs.aio-max-nr tunable
  * new release (2.19.0)
  * packit: s/synced_files/files_to_sync/
  * packit: metadata field is no longer needed
  * packit: build SRPM in Copr
  * profiles: drop sched_ tuning from openshift-control-plane
  * new release (2.19.0-rc.1)
  * builtin functions: added calc_isolated_cores function
  * spec: dropped weak deps where not needed
  * Update tuned-adm.bash
  * TuneD plug-in documentation.
  * Adding mtu command to net plugin
  * openshift profile: tuning for NVMe devices
  * Add version/help command automatic complete
  * Do not hardcode disk name in tuned initrd path.
  * bootloader: cmdline parser change and fixed escaping
  * Fix in polkit authorization.
  * realtime: Set tsc as 'reliable'
  * recommend: do not ignore syspurpose_role if there is no syspurpose
  * Fixing arguments in disk plugin method
  * Default delimiters causing errors in some specific situations, inline comments
  * gui: fixed possible traceback in the save_profile
  * Striping quotes	when unpacking cpu list
  * profiles: improve regexes to match kernel threads
* Thu Aug 11 2022 Callum Farmer <gmbr3@opensuse.org>
- Use %%_modprobedir
- Move dbus-1 system.d file to /usr (bsc#1202339)
* Tue Apr 26 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_prefix}/lib/kernel and subdirectories: fix build on
  Factory.
* Tue Mar 15 2022 trenn@suse.de
- Add new openshift platform profiles
- Instead of adding all profiles to main package and exclude subpackage
  profiles, explicitly mention all added profiles in %%files section
- Sort (alphabetically) profiles and packages
- Update to version 2.18.0.8+git.6f907c9:
  * beakerlib: fix systemd rate limiting for variables-support-in-profiles
  * scheduler: fix construction of the process name regex
  * Added more conflicting implementations to the systemd unit file.
  * raise the netfilter hash table size in openshift/atomic-{host,guest} to match the max netfilter conntrack entries, reducing such hash table load.
  * Fixing save call and comments in tuned gui
  * Adding option "txqueuelen" to net_plugin
  * bootloader: on s390(x) remove TuneD variables from the BLS
  * daemon: don't do full rollback on systemd failure
  * profiles: use cstate.id_no_zero instead of the cstate.id
  * Expanding cpu plugin force_latency option syntax
  * Adding support for nvme subsystem block devices and adding tests so it won't throw errors on hdparms commands.
  * Fix improper parsing of include directive
  * application: log TuneD and kernel version
  * readme: mention conflicting cpupower and power-profiles-daemon
  * dbus: fix traceback on python-2.7
  * cpu_partitioning: fixed no_balance_cores on newer kernels
  * spec: do not require subscription-manager on CentOS
  * Add conditional profile loading
  * openshift profile: workaround high CPU utilization of [scheduler] plug-in.
  * scheduler: new option cgroup_ps_blacklist
  * breaking up various modules and implementing neccessary new syntax used downstream to keep docs repos synced
* Fri Sep 10 2021 trenn@suse.de
- Update to version 2.16.0:
  * bootloader: make skip_grub_config consistent with initrd_remove_dir
* Fri Jul  9 2021 trenn@suse.de
- Update to version 2.15.0+git.1625694366.bc3f737:
  * bootloader: support for systems that don't have grub installed
  * Removing depedency on python-decorator package.
  * Adding support for rpm-ostree system to bootloader plugin.
  * profiles: drop sched_ tuning where appropriate
  * scheduler: abstract sched_ and numa_ knobs
  * realtime-virtual-*: Set irqaffinity through kernel command line
  * After error while switching profiles attribute _active_profiles is not changed back.
    That causes issues with wrong signals (and also more issues with restart after etc)
- Enhance _service file
* Mon Apr 19 2021 trenn@suse.de
- Update _service file to always get latest sources from github
  master branch and auto-set version correctly
- Update to version v2.15.0+git.20210416.e828fa8:
  * plugin_net: Fix check for channels supported mode
  * udev: explicitly sort udev properties
  * powertop2tuned: work with PowerTOP 2.13 and newer
  * Changes to scheduler plugin to support os interface instead of schedutils in newer python versions.
  * Lower the threading.Event's wait() timeout.
  * added postgresql server profile
  * spectrumcale-ece: package the profile to own subpackage
* Mon Nov 30 2020 Thomas Renninger <trenn@suse.de>
- Update to version 2.14.0
  Changelog entry below (from 19. Aug. 2020) is wrong.
  Mainline has the profiles in /usr/lib,
  so let's better stay there, too. This also fixes bsc#1175932.
  Patch is not needed anymore with latest mainline changes:
  D adjust_README_path_in_manpage.patch
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Dot not mangle _tmpfilesdir: all half-way decent distros define
  this already.
- Define profile_dir as %%{_libexecdir}/%%{name}: stay closer in line
  with what upstream actually coded (with the change of libexecdir
  to /usr/libexec in Tumbleweed, we are in the equal path now).
* Thu Jun 11 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.13.0. Note that the previous version was not
  in fact 2.22.0, but commit 8c9df99, 28 commits before 2.13.0.
* Mon Feb  3 2020 trenn@suse.de
- Add /etc/dbus-1/system.d directory to file section as done in other
  packages (double checked with wicked) to avoid build error:
  tuned-2.4.1-9.10.1.noarch.rpm: directories not owned by a package:
  - /etc/dbus-1
  - /etc/dbus-1/system.d
* Tue Nov 26 2019 trenn@suse.de
- Update to latest 2.22.0 release
  includes bug fix for bsc#1139249
- Use self defined profile_dir instead of _libexecdir
- Always add pmqos-static.py
  This was wrongly bound to profiles-nfv package
- Remove defirqaffinity
  It is not called anymore. Merge request pending:
  https://github.com/redhat-performance/tuned/pull/223
* Mon Jul  1 2019 trenn@suse.de
- Upgrade to latest 2.12.0 version(git commit b514cda168878c330b70416676)
  - Removes sap-hana-vmware profile
* Tue May 28 2019 trenn@suse.de
- Limit /var/log/tuned directory permissions to 750
* Thu Apr 11 2019 trenn@suse.de
- Adjust README path in manpage (bsc#1131858)
  A adjust_README_path_in_manpage.patch
* Tue Mar 12 2019 trenn@suse.de
- Upgrade to latest git HEAD (v2.11.0 + latest fixes):
  commit b4d9dfc31c46ed9cda100f03227ac5be087d3d74
  Date:   Fri Apr 5 10:49:17 2019 +0200
- tuned gui does not need polkit anymore as it can now run as non-root
  user
- Fixes bsc#1126609
- Includes this patch:
  D tuned_differ_x86_and_other_archs_in_cpu_plugin.patch
* Wed Jan 16 2019 trenn@suse.de
- Differ archs and x86 CPU vendors to avoid wrong warning about a
  missing intel tool (x86_energy_perf_bias)
- Remember arch and x86 CPU vendor to allow arch/vendor specific
  CPU tunings in the future (fate#326694)
  A tuned_differ_x86_and_other_archs_in_cpu_plugin.patch
- Require virt-what to be able to detect whether it is running
  on a virtual machine
* Fri Jan 11 2019 trenn@suse.de
- Update to latest git head commit 26db89de18efad1b4536
  including quite some mainline fixes
- tuned needs polkit daemon running
* Thu Jan  3 2019 trenn@suse.de
- Remove sap subpackages entirely for SLE and Leap products.
  These conflict with possible other SLE optimized sap subpackages
  (bnc#1064832).
- Create systemd tmpfiles correctly for different releases again.
* Tue Dec 25 2018 Martin Herkt <9+suse@cirno.systems>
- Add missing dependency on python3-linux-procfs
* Thu Nov 22 2018 trenn@suse.de
- Go for 2.10.0 full version in _service (even this is rc1)
  bsc#1071436
  Latest included git commit:
  commit 3722b151920dc20735dc15cbd45aed7b573fdfc2
  Date:   Wed Nov 21 14:21:32 2018 +0100
  Still keep the old git version parameter commented out, maybe
  I need this again.
- Since cpupower also has perf_bias binary, the cpupower call to
  switch this has been reverted to lower maintenance overhead
  D    check_for_cpupower.patch
  D    use-cpupower-for-intel-perf-bias.patch
- Update to version 2.10.0:
  * Add range feature for cpu exclusion
  * Disable KSM only once, re-enable it only on full rollback
  * Add log message for unsupported parameters in plugin_net
  * Add missing feature parameters aliases to plugin_net
  * Make virtual-host identical to latency-performance
* Fri Apr  6 2018 tchvatal@suse.com
- Reintroduce the _service file as we must use git head in order to
  get all the python3 fixes in
- Update to version 2.9.0+git20180328.d25e8b8:
  * makefile: dropped KVM unit tests, now provided by standalone package
  * sysctl: support assignment modifiers as other plugins do
  * spec: used weak deps for tuned-profiles-nfv-host-bin
  * Added requires to tuned-profiles-nfv-host-bin
  * Dropped tuned-profiles-nfv-host-bin subpackage
  * tuned: Add readahead comment to throughput-performance tuned.conf
  * oracle: fixed ip_local_port_range parity warning
  * Consistently use 'balance' instead of 'rebalance' in cpu-partitioning
- Rebase check_for_cpupower.patch to apply cleanly again
* Fri Apr  6 2018 tchvatal@suse.com
- Version update to 2.9.0:
  * python3 porting start
  * various small fixes
- Drop patches merged upstream:
  * fix-desktop-category.patch
  * remove-unnecessary-shebangs.patch
  * fix-glade-file-permission.patch
- Switch to autopatch from calling all individual patchlines
* Fri Apr  6 2018 tchvatal@suse.com
- Switch to python3 and format with spec-cleaner
* Fri Apr  6 2018 tchvatal@suse.com
- Switch to normal url fetching, there is no actual reason to run
  service in order to generate the versioned tarballs
* Fri Feb 16 2018 dimstar@opensuse.org
- Own %%{_sysconfdir}/dbus-1/system.d and %%{_sysconfdir}/dbus-1: in
  the past systemd happened to install things there and 'own' the
  directory for us, but that was just a coincidence.
- Replace systemd BuildRequires with pkgconfig(systemd), allowing
  OBS to pick systemd-mini for the build.
* Thu Nov 16 2017 jloeser@suse.com
- check for `cpupower` binary and set attribute correctly (bsc#1055070)
- added patch:
  * check_for_cpupower.patch
* Fri Jul  7 2017 fschnizlein@suse.com
- Update to version 2.8.0:
  * builtin functions: parser not traceback if func expands to empty string
  * systemd: added support for older systemd CPUAffinity syntax
  * scheduler: do not traceback if process dissapears during enumeration
  * scheduler: fix more python-linux-procfs tracebacks
  * plugin_net: Fix invocation of execute()
  * cpu-partitioning: use tuna for cores isolation
  * builtin functions: add strip
  * bootloader: workaround for adding tuned_initrd to new kernels on restart
  * new release (2.8.0)
  + Add Patch: Fix category in desktop file for tuned-gui (fix-desktop-category.patch)
  + Add Patch: Remove unnecessary shebangs (remove-unnecessary-shebangs.patch)
  + Add Patch: Fix file permission for glade file (fix-glade-file-permission.patch)
  + Add rpmlintrc to silence unnecessary warnings
  + Remove Patch: tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
  = Modified Patches to apply with 2.8.0:
  - fix-allow-receive_sender-default.patch
  - use-cpupower-for-intel-perf-bias.patch
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 2.6.0
  * plugin_cpu: do not show error if cpupower or
    x86_energy_perf_policy are missing
  * plugin_sysctl: fixed quoting of sysctl values
  * tuned-adm: added log file location hint to verify command output
  * libexec: fixed listdir and isdir in defirqaffinity.py
  * plugin_cpu: save and restore only intel pstate attributes that
    were changed
  * functions: fixed sysfs save to work with options
  * plugins: added scsi_host plugin
  * tuned-adm: fixed restart attempt if tuned is not running
  * spec: fixed post scriptlet to work without grub
  * tuned-profiles-nfv: fix find-lapictscdeadline-optimal.sh for
    CPUS where ns > 6500
  * functions: fixed restore_logs_syncing to preserve SELinux
    context on rsyslog.conf
  * realtime: set unboud workqueues cpumask
  * spec: correctly remove tuned footprint from /etc/default/grub
  * gui: fixed creation of new profile
  * profiles: removed nohz_full from the realtime profile
  * profiles: Added nohz_full and nohz=on to realtime guest/host
    profiles
  * profiles: fixed lapic_timer_adv_ns cache
  * plugin_sysctl: pass verification even if the option doesn't
    exist
  * added support for 'summary' and 'description' of profiles,
    extended D-Bus API for better Cockpit support
* Tue Sep 29 2015 mpluskal@suse.com
- Fix build for openSUSE Leap (lack of tmpfiles.d macro)
* Mon Aug 17 2015 mpluskal@suse.com
- Update to 2.5.1
  * plugin_scheduler: work with nohz_full (rhbz#1247184)
  * fixed realtime-virtual-guest/host profiles packaged twice
    (rhbz#1249028)
  * fixed requirements of realtime and nfv profiles
  * fixed tuned-gui not starting (boo#937647)
  * various other minor fixes
* Tue Jul 14 2015 mpluskal@suse.com
- tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
  * fixed indentation and tabs usage
* Sun Jul 12 2015 mpluskal@suse.com
- Update to 2.5.0
  * add tuned-adm verify command for verification if all settings
    from profile was applied (rhbz#1212836)
  * add variables support to profiles / scripts (rhbz#1225124)
  * add support for calling built-in functions when expanding
    variables, built-in functions can be provided by function
    plugins, add some built-in functions for unit conversion
    (rhbz#1225135)
  * add support for no daemon mode (rhbz#1068663)
  * add oracle tuned profile (rhbz#1196298)
  * add tuned profile for RHEL-RT (rhbz#1228801)
  * add tuned profiles for RHEL-NFV (rhbz#1228803)
  * plugin_scheduler: added support for runtime tuning of
    processes using perf (rhbz#1148546)
  * plugin_sysfs: add glob support (rhbz#1212831)
  * plugin_net: add support for ethtool -C (rhbz#1152539)
  * plugin_net: add support for ethtool -K (rhbz#1152541)
  * plugin_bootloader: add support for calculation of values for
    the kernel command line (rhbz#1191595)
  * tuned-adm: fix bash completions (rhbz#1207668)
  * plugin_bootloader: do not install tuned kernel command line to
    rescue kernels (rhbz#1223864)
  * add support for changing elevators on xvd* devices
    (Amazon EC2) (rhbz#1170152)
  * do not change settings of transparent hugepages if set in
    kernel cmdline (rhbz#1189868
- Rebase patch:
  * tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
- Drop patch included in upstream
  * tuned-powertop2tuned-fix-KeyError-on-id-attribute.patch
- Fix some rpmlint warnings
  * ghost rundif
  * create tpmfiles in post using proper macro
- Small cleanups using spec-cleaner
* Fri Jul 10 2015 bwiedemann@suse.com
- fix syntax (bnc#937647)
* Mon Jan  5 2015 p.drouand@gmail.com
- Add tuned-powertop2tuned-fix-KeyError-on-id-attribute.patch;
  fix bnc#888599
* Fri Oct 17 2014 oholecek@suse.com
- Update to version 2.4.1
  + plugin_disk: set_spindown and set_APM made independent (rhbz#976725)
  + plugin_bootloader: added check for grub2 (rhbz#1150047)
  + tuned-adm: fixed traceback on "tuned-adm list" (rhbz#1149162)
  + plugin_bootloader: 00_tuned do not return error if there is no cmdline (rhbz#1151768, bsc#901180)
  + fixed polkit configuration
- Remove tuned-2.4.0-polkit-tuned-gui-path.patch
* Sat Oct 11 2014 p.drouand@gmail.com
- Remove python-gobject dependency in -gtk subpackage; main package
  already requires python-gobject
* Fri Oct 10 2014 p.drouand@gmail.com
- Update to version 2.4.0
  + rebase tuned to latest upstream (rhbz#1093883)
  + fixed traceback if profile cannot be loaded
    related: rhbz#953128
  + powertop2tuned: fixed traceback if rewriting file instead of dir
    resolves: rhbz#963441
  + throughput-performance: altered dirty ratios for better performance
    resolves: rhbz#1043533
  + latency-performance: leaving THP on its default
    resolves: rhbz#1064510
  + used throughput-performance profile on server by default
    resolves: rhbz#1063481
  + network-latency: added new profile
    resolves: rhbz#1052418
  + network-throughput: added new profile
    resolves: rhbz#1052421
  + recommend.conf: fixed config file
    resolves: rhbz#1069123
  + systemd: added cpupower.service conflict
    resolves: rhbz#1073392
  + balanced: used medium_power ALPM policy
  + added support for >, < assignment modifiers in tuned.conf
  + handled root block devices
  + balanced: used conservative CPU governor
    resolves: rhbz#1124125
  + plugins: added selinux plugin
  + plugin_net: added nf_conntrack_hashsize parameter
  + profiles: added atomic-host profile
    resolves: rhbz#1091977
  + profiles: added atomic-guest profile
    resolves: rhbz#1091979
  + moved profile autodetection from post install script to tuned daemon
    resolves: rhbz#1144067
  + profiles: included sap-hana and sap-hana-vmware profiles
  + man: structured profiles manual pages according to sub-packages
  + added missing hdparm dependency
    resolves: rhbz#1144858
  + improved error handling of switch_profile
    resolves: rhbz#1068699
  + tuned-adm: active: detect whether tuned deamon is running
    related: rhbz#1068699
  + removed active_profile from RPM verification
    resolves: rhbz#1104126
  + plugin_disk: readahead value can be now specified in sectors
    resolves: rhbz#1127127
  + plugins: added bootloader plugin
    resolves: rhbz#1044111
  + plugin_disk: added error counter to hdparm calls
  + plugins: added scheduler plugin
    resolves: rhbz#1100826
  + added tuned-gui
- Add tuned-2.4.0-polkit-tuned-gui-path.patch; fix tuned-gui path
  in polkit policy rule
- Remove fix-new-systemd-tmpfiles.d-path.patch; fixed by upstream
- Update use_cpupower_for_intel_perf_bias to upstream changes
  + Added : tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
  + Deleted : se_cpupower_for_intel_perf_bias
- Add tuned-gtk, profiles-sap, profiles-sap-hana, and profiles-atomic
  subpackages
- Add hdparm and util-linux requirements; new dependencies
- Add bash-completion build requirement to avoid owning standard
  directory
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Mon Mar 31 2014 trenn@suse.de
- Use cpupower {info,set} -b to set Intel perf bias value instead of
  x86_energy_perf_policy we do not ship.
  Add use_cpupower_for_intel_perf_bias
- Add rctuned service link in /usr/sbin
- Mark pm-profiler obsoleted by this package
* Fri Feb 21 2014 p.drouand@gmail.com
- Add fix-allow-receive_sender-default.patch  allow receive_* is
  normally not needed as that is the default
* Sun Feb  2 2014 cfarrell@suse.com
- license update: GPL-2.0+
  No sign of GPL-2.0 (only) licensed components
* Sun Dec 22 2013 p.drouand@gmail.com
- Update to version 2.3.0
  + audio plugin: fixed audio settings in standard profiles
    resolves: rhbz#1019805
  + video plugin: fixed tunings
  + daemon: fixed crash if preset profile is not available
    resolves: rhbz#953128
  + man: various updates and corrections
  + functions: fixed usb and bluetooth handling
  + tuned: switched to lightweighted pygobject3-base
  + daemon: added global config for dynamic_tuning
    resolves: rhbz#1006427
  + utils: added pmqos-static script for debug purposes
    resolves: rhbz#1015676
  + throughput-performance: various fixes
    resolves: rhbz#987570
  + tuned: added global option update_interval
  + plugin_cpu: added support for x86_energy_perf_policy
    resolves: rhbz#1015675
  + dbus: fixed KeyboardInterrupt handling
  + plugin_cpu: added support for intel_pstate
    resolves: rhbz#996722
  + profiles: various fixes
    resolves: rhbz#922068
  + profiles: added desktop profile
    resolves: rhbz#996723
  + tuned-adm: implemented non DBus fallback control
  + profiles: added sap profile
  + tuned: lowered CPU usage due to python bug
    resolves: rhbz#917587
- Add missing requirements; ethtool, gawk, python-pyudev and powertop
- Replace python-gobject2 with python-gobject in requirements;
  python-gobject2 is depreciated
- Remove unwanted stuff instead of exclude it
* Sun Oct 20 2013 hrvoje.senjan@gmail.com
- Adjust Requires again: we are openSUSE, not Fedora, so require
  python-gobject2 instead of non-existant pygobject2
* Tue Oct 15 2013 hrvoje.senjan@gmail.com
- Update to version 2.2.2:
  * cpu plugin: fixed cpupower workaround
  * cpu plugin: fixed crash if cpupower is installed
- Changes since 2.2.1:
  * audio plugin: fixed error handling in _get_timeout
  * removed cpupower dependency, added sysfs fallback
  * powertop2tuned: fixed parser crash on binary garbage
  * cpu plugin: dropped multicore_powersave as kernel upstream
    already did
  * plugins: options manipulated by dynamic tuning are now
    correctly saved and restored
  * powertop2tuned: added alias -e for --enable option
  * powertop2tuned: new option -m, --merge-profile to select
    profile to merge
  * prefer transparent_hugepage over redhat_transparent_hugepage
  * recommend: use recommend.conf not autodetect.conf
  * tuned.service: switched to dbus type service
  * tuned: new option --pid, -P to write PID file
  * tuned, tuned-adm: added new option --version, -v to show version
  * disk plugin: use APM value 254 for cleanup / APM disable
    instead of 255
  * tuned: new option --log, -l to select log file
  * powertop2tuned: avoid circular deps in include
    (one level check only)
  * powertop2tuned: do not crash if powertop is not installed
  * net plugin: added support for wake_on_lan static tuning
  * loader: fixed error handling
- Require dbus-1-python instead of dbus-python, so the package is
  made installable
* Fri Feb  8 2013 p.drouand@gmail.com
- Update to version 2.2.0:
  * remove nobarrier from virtual-guest (data loss prevention)
  * devices enumeration via udev, instead of manual retrieval
  * support for dynamically inserted devices (currently disk plugin)
  * dropped rfkill plugins (bluetooth and wifi), the code didn't work
- Add Requires:python-configobj tag needed for profiles configuration
* Mon Dec 24 2012 p.drouand@gmail.com
- Update to 2.1.1 version:
  * fix: powertop2tuned execution
  * fix: ownership of /etc/tuned
  * daemon: allow running without selected profile
  * daemon: fix profile merging, allow only safe characters in profile names
  * daemon: implement missing methods in DBus interface
  * daemon: implement profile recommendation
  * daemon: improve daemonization, PID file handling
  * daemon: improved device matching in profiles, negation possible
  * daemon: various internal improvements
  * executables: check for EUID instead of UID
  * executables: run python with -Es to increase security
  * plugins: cpu - fix cpupower execution
  * plugins: disk - fix option setting
  * plugins: mounts - new, currently supports only barriers control
  * plugins: sysctl - fix a bug preventing settings application
  * powertop2tuned: speedup, fix crashes with non-C locales
  * powertop2tuned: support for powertop 2.2 output
  * profiles: progress on replacing scripts with plugins
  * tuned-adm: bash completion - suggest profiles from all supported locations
  * tuned-adm: complete switch to D-bus
  * tuned-adm: full control to users with physical access
- Add a %%post script to try to autodetect the best profile
- Update the patches
- Change subpackages to be more coherent and for don't oblige to install
  useless packages by user
* Tue Oct 30 2012 p.drouand@gmail.com
- Remove rpmlintrc for being acceptable on Factory
* Tue Oct 30 2012 p.drouand@gmail.com
- Use %%doc for the doc files - that will put them automatically into
  /usr/share/doc/packages/tuned. Do not use /usr/share/doc/tuned-%%version
  at all
* Tue Oct 30 2012 p.drouand@gmail.com
- Add %%py_compiles macro for bitcompile .py files
- Add fix-new-systemd-tmpfiles.d-path.patch to fix tmpfiles.d
  directory
* Tue Oct 30 2012 p.drouand@gmail.com
- Update to 2.0.2 version:
  * No changelog available
- Remove compat-profiles: no versions < 2.0 have been provided
* Thu Oct  4 2012 p.drouand@gmail.com
- Some changes to be more "Suse-like":
  * add systemd suse macro
- Add a patch to fix allow receive
* Fri Sep 28 2012 p.drouand@gmail.com
- Initial release of tuned
